.. _developers:

Developers
==========

If you are a developer and are willing to hack on Pootle or contribute in some
other way, make sure to read through this part.

.. toctree::
   :maxdepth: 2

   contributing
   roadmap
   hacking
   setup_linux
   setup_windows
   frontend
   customization
   browsers
   testing
   release
   glossary
   styleguide
   deprecation
   releasing
   plugins
